@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 """
 TEST.DBTOOLS.TEST_DBTOOLS.PY -- test script for state machine class
-Copyright (C) 2008-2021 by Peter A. Donis
+Copyright (C) 2008-2022 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -105,8 +105,13 @@ class MySQLTest(DBToolsTest, unittest.TestCase):
     
     def setUp(self):
         # Must have externally reachable empty DB available
-        from plib.stdlib.jsontools import load_json
-        self.kwds = dict(db=self.dbname, **load_json(self.cred_filename))
+        # Credentials in self.cred_filename
+        # If file does not exist, assume test must be skipped
+        if not os.path.isfile(self.cred_filename):
+            self.skipTest("MySQL database not available, skipping that database type")
+        else:
+            from plib.stdlib.jsontools import load_json
+            self.kwds = dict(db=self.dbname, **load_json(self.cred_filename))
     
     def tearDown(self):
         # The test clears all tables at the end, so the DB should be empty again
